@@ -8,7 +8,8 @@ use DBIx::DataModel::Meta::Utils;
 use Carp;
 use Params::Validate qw/HASHREF ARRAYREF SCALAR/;
 use List::MoreUtils  qw/any/;
-use namespace::autoclean;
+
+use namespace::clean;
 
 {no strict 'refs'; *CARP_NOT = \@DBIx::DataModel::CARP_NOT;}
 
